@@ -683,6 +683,10 @@ void handle_facility_confirmation_supplementary(
 				name, PLCI);
 		}
 		break;
+	case 0x000d: /* CD */
+		cc_verbose(2, 1, VERBOSE_PREFIX_3 "%s: CD confirmation (0x%04x) (PLCI=%#x)\n",
+			name, serviceinfo, PLCI);
+		break;
 	case 0x000f: /* CCBS request */
 		cc_verbose(2, 1, VERBOSE_PREFIX_3 "%s: CCBS request confirmation (0x%04x) (PLCI=%#x)\n",
 			name, serviceinfo, PLCI);
